@@ -4,7 +4,7 @@
 #include <elf.h>
 
 int killrpath(const char *filename);
-int chrpath(const char *filename, const char *newpath);
+int chrpath(const char *filename, const char *newpath, int convert);
 
 int elf_open(const char *filename, int flags, Elf32_Ehdr *ehdr);
 void elf_close(int fd);
